==> glirc-2.39.0.1-241-x86_64.pkg.tar.zst: usr/share/haskell/register/glirc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 glirc
version:              2.39.0.1
visibility:           public
id:                   glirc-2.39.0.1-4reAlxDgjyF41DM3coxqoQ
key:                  glirc-2.39.0.1-4reAlxDgjyF41DM3coxqoQ
license:              ISC
copyright:            2016-2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             Console IRC client
description:
    Console IRC client

    glirc is a console IRC client with an emphasis on providing
    dynamic views into the model of your IRC connections.

    <https://github.com/glguy/irc-core/wiki Documentation Wiki>

category:             Network
abi:                  36ffbc8721c8e0ffe4f7d994cccf7634
exposed:              True
exposed-modules:
    Client.Authentication.Ecdh Client.Authentication.Ecdsa
    Client.Authentication.Scram Client.CApi Client.CApi.Exports
    Client.CApi.Types Client.Commands Client.Commands.Arguments.Parser
    Client.Commands.Arguments.Renderer Client.Commands.Arguments.Spec
    Client.Commands.Certificate Client.Commands.Channel
    Client.Commands.Chat Client.Commands.Connection
    Client.Commands.Exec Client.Commands.Interpolation
    Client.Commands.Operator Client.Commands.Queries
    Client.Commands.Recognizer Client.Commands.TabCompletion
    Client.Commands.Toggles Client.Commands.Types
    Client.Commands.Window Client.Commands.WordCompletion
    Client.Commands.ZNC Client.Configuration
    Client.Configuration.Colors Client.Configuration.Macros
    Client.Configuration.ServerSettings Client.Configuration.Sts
    Client.EventLoop Client.EventLoop.Actions Client.EventLoop.Errors
    Client.EventLoop.Network Client.Hook Client.Hook.DroneBLRelay
    Client.Hook.Matterbridge Client.Hook.Snotice
    Client.Hook.Znc.Buffextras Client.Hooks Client.Image
    Client.Image.Layout Client.Image.LineWrap Client.Image.Message
    Client.Image.MircFormatting Client.Image.PackedImage
    Client.Image.Palette Client.Image.StatusLine Client.Image.Textbox
    Client.Log Client.Mask Client.Message Client.Network.Async
    Client.Network.Connect Client.Options Client.State
    Client.State.Channel Client.State.EditBox
    Client.State.EditBox.Content Client.State.Extensions
    Client.State.Focus Client.State.Network Client.State.Window
    Client.UserHost Client.View Client.View.Cert
    Client.View.ChannelInfo Client.View.Digraphs Client.View.Help
    Client.View.IgnoreList Client.View.KeyMap Client.View.MaskList
    Client.View.Mentions Client.View.Messages Client.View.Palette
    Client.View.RtsStats Client.View.UrlSelection Client.View.UserList
    Client.View.Windows

hidden-modules:
    ContextFilter DigraphQuote Digraphs LensUtils RtsStats StrQuote
    StrictUnit Paths_glirc Build_glirc

import-dirs:          /usr/lib/ghc-9.2.8/site-local/glirc-2.39.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/glirc-2.39.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/glirc
hs-libraries:         HSglirc-2.39.0.1-4reAlxDgjyF41DM3coxqoQ
include-dirs:         /usr/lib/ghc-9.2.8/site-local/glirc-2.39.0.1/include
includes:             include/glirc-api.h
depends:
    HsOpenSSL-0.11.7.9-5ytlFLsiQtz4KzIXsTXbcz
    async-2.2.5-GOT0v2vzV5iH7iWkyOUIC3
    attoparsec-0.14.4-IDdHCXuvqZFAtv2X99gOjm base-4.16.4.0
    base64-bytestring-1.2.1.0-46pt6JzDe5g8aYRwkMhuBg
    bytestring-0.11.4.0 config-schema-1.3.0.0-HrKAIa8Pegj8Iznvbvv2xG
    config-value-0.8.3-8yCRuGm4wH18pEPQuVa8HA containers-0.6.5.1
    curve25519-0.2.8-7NMmC7eDuaI3ekvM9RcWiK directory-1.3.6.2
    filepath-1.4.2.2 free-5.1.10-JYBndQTLyvuDhhk4wr5zld
    githash-0.1.6.3-3JNji6eHZdzAH4B3dLnMKm
    hashable-1.4.4.0-JynHLbpSPE72B4j6uWctY4
    hookup-0.8-DcNd4A87DzzC2WZMvgCHQa
    irc-core-2.11-NoXwLZcNM318lNSnubt1N
    kan-extensions-5.2.6-2SLfqkiW3o3Iw7hKqFPAce
    lens-5.2.3-FaAjdvRjDs8BQhMYQYzR8W
    network-3.1.4.0-JL8MfxNaZmuAIivQBcxkBq process-1.6.16.0
    psqueues-0.2.8.0-HBRI5F2y8X0KZNolpnWNjY
    random-1.2.1.2-5cse3egicJy98i0Qegn8w0
    regex-tdfa-1.3.2.2-GVtzYoUSlJyBUw9nALJHnM
    split-0.2.5-1asvxxLzz3P40WkIiqLwMi stm-2.5.0.2
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.20-AzoOiKjV26Z32LkoSmNfI7
    vector-0.13.1.0-JX40x5KeA95953did9SvPW
    vty-5.39-JAuclaXBzSQ9moYbJUC419

haddock-interfaces:   /usr/share/doc/glirc/html/glirc.haddock
haddock-html:         /usr/share/doc/glirc/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> glirc-2.39.0.1-243-x86_64.pkg.tar.zst: usr/share/haskell/register/glirc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 glirc
version:              2.39.0.1
visibility:           public
id:                   glirc-2.39.0.1-CF1IseuKjn05v20vr271xP
key:                  glirc-2.39.0.1-CF1IseuKjn05v20vr271xP
license:              ISC
copyright:            2016-2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             Console IRC client
description:
    Console IRC client

    glirc is a console IRC client with an emphasis on providing
    dynamic views into the model of your IRC connections.

    <https://github.com/glguy/irc-core/wiki Documentation Wiki>

category:             Network
abi:                  36cece50fa7a386f403621436ead8979
exposed:              True
exposed-modules:
    Client.Authentication.Ecdh Client.Authentication.Ecdsa
    Client.Authentication.Scram Client.CApi Client.CApi.Exports
    Client.CApi.Types Client.Commands Client.Commands.Arguments.Parser
    Client.Commands.Arguments.Renderer Client.Commands.Arguments.Spec
    Client.Commands.Certificate Client.Commands.Channel
    Client.Commands.Chat Client.Commands.Connection
    Client.Commands.Exec Client.Commands.Interpolation
    Client.Commands.Operator Client.Commands.Queries
    Client.Commands.Recognizer Client.Commands.TabCompletion
    Client.Commands.Toggles Client.Commands.Types
    Client.Commands.Window Client.Commands.WordCompletion
    Client.Commands.ZNC Client.Configuration
    Client.Configuration.Colors Client.Configuration.Macros
    Client.Configuration.ServerSettings Client.Configuration.Sts
    Client.EventLoop Client.EventLoop.Actions Client.EventLoop.Errors
    Client.EventLoop.Network Client.Hook Client.Hook.DroneBLRelay
    Client.Hook.Matterbridge Client.Hook.Snotice
    Client.Hook.Znc.Buffextras Client.Hooks Client.Image
    Client.Image.Layout Client.Image.LineWrap Client.Image.Message
    Client.Image.MircFormatting Client.Image.PackedImage
    Client.Image.Palette Client.Image.StatusLine Client.Image.Textbox
    Client.Log Client.Mask Client.Message Client.Network.Async
    Client.Network.Connect Client.Options Client.State
    Client.State.Channel Client.State.EditBox
    Client.State.EditBox.Content Client.State.Extensions
    Client.State.Focus Client.State.Network Client.State.Window
    Client.UserHost Client.View Client.View.Cert
    Client.View.ChannelInfo Client.View.Digraphs Client.View.Help
    Client.View.IgnoreList Client.View.KeyMap Client.View.MaskList
    Client.View.Mentions Client.View.Messages Client.View.Palette
    Client.View.RtsStats Client.View.UrlSelection Client.View.UserList
    Client.View.Windows

hidden-modules:
    ContextFilter DigraphQuote Digraphs LensUtils RtsStats StrQuote
    StrictUnit Paths_glirc Build_glirc

import-dirs:          /usr/lib/ghc-9.2.8/site-local/glirc-2.39.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/glirc-2.39.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/glirc
hs-libraries:         HSglirc-2.39.0.1-CF1IseuKjn05v20vr271xP
include-dirs:         /usr/lib/ghc-9.2.8/site-local/glirc-2.39.0.1/include
includes:             include/glirc-api.h
depends:
    HsOpenSSL-0.11.7.9-4Z5EgFrzAIIPCctwRyeao
    async-2.2.5-C7wSBqUZtbTIGwzJcB5Zmf
    attoparsec-0.14.4-Ls3KkFW9Y1ID7Dl0hM2meR base-4.16.4.0
    base64-bytestring-1.2.1.0-EN8wQYcxk0e9hsUIf9btXq
    bytestring-0.11.4.0 config-schema-1.3.0.0-BZ2u95KgjKTBfnXDd0I9aX
    config-value-0.8.3-8yCRuGm4wH18pEPQuVa8HA containers-0.6.5.1
    curve25519-0.2.8-IGYsPRJVsPTB395VxwPNd2 directory-1.3.6.2
    filepath-1.4.2.2 free-5.1.10-5sFlxwF01A87B8Qo7eTrZb
    githash-0.1.6.3-1oQDf5fvnsFJmPgaEqiRPp
    hashable-1.4.4.0-4PDYVYgOfaOHbKjFqbnqvX
    hookup-0.8-GuBy9RDExMqFdYa9164Q8E
    irc-core-2.11-HkLZcMbyIR3KnQ6JoBRo8
    kan-extensions-5.2.6-3k9VLURBaRu75iUp27keRl
    lens-5.2.3-HSZB5kpZAt0LoMCL0cbf2Z
    network-3.1.4.0-9o776rElF80EJr5kgfplYq process-1.6.16.0
    psqueues-0.2.8.0-FBlNLTCwyWS8uG4Pqandst
    random-1.2.1.2-AYM6DIIc9ftFlQ8RzN1HJP
    regex-tdfa-1.3.2.2-1xhjl1IlCf4FpybsqAXAC1
    split-0.2.5-BYOFqeTExQMGx7basqXlD8 stm-2.5.0.2
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.20-E7OuZmBexWvK28rs1X57rg
    vector-0.13.1.0-1cpgbj3eXUqGZ3uVszXgJ9
    vty-5.39-6R3ayT2gn0u7reMhlML2RD

haddock-interfaces:   /usr/share/doc/glirc/html/glirc.haddock
haddock-html:         /usr/share/doc/glirc/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
